@@ -8,7 +8,7 @@ use warnings;
 
 package Geo::Shape;
 use vars '$VERSION';
-$VERSION = '0.90';
+$VERSION = '0.91';
 
 
 use Geo::Proj;      # defines wgs84
@@ -23,7 +23,6 @@ use Carp            qw/croak confess/;
 
 
 use overload '""'     => 'string'
-           , '=='     => 'equal'
            , bool     => sub {1}
            , fallback => 1;
 
@@ -109,14 +108,6 @@ sub distance($;$)
 }
 
 
-sub equal($;$)
-{ confess "INTERNAL: equal() not implemented for ".ref(shift) }
-
-
-sub sameAs($$)
-{ confess "INTERNAL: sameAs() not implemented for ".ref(shift) }
-
-
 sub bboxRing(@)
 {   my ($thing, $xmin, $ymin, $xmax, $ymax, $proj) = @_;
 
